| Title: | Interface Between SVN and R |
|---|---|
| Description: | Get information on SVN repositories through R. Explore file status, commit logs etc. |
| Authors: | Alan Haynes |
| Maintainer: | Alan Haynes <[email protected]> |
| License: | MIT |
| Version: | 0.4.0 |
| Built: | 2026-05-23 09:38:30 UTC |
| Source: | https://github.com/dcr-unibe-ch/svn |
Find conflicts in repo
svn_conflict(path_to_repo = NULL)svn_conflict(path_to_repo = NULL)
path_to_repo |
path(s) to the folder(s) whose status to query (if NULL it uses the working directory). Can be a vector. |
character vector of conflicts (tree or otherwise)
# svn_conflict(path_to_some_repo)# svn_conflict(path_to_some_repo)
get details on the status of an svn repo
svn_details(path_to_repo = NULL)svn_details(path_to_repo = NULL)
path_to_repo |
path(s) to the folder(s) whose status to query (if NULL it uses the working directory). Can be a vector. |
character
# svn_details()# svn_details()
Log of commits in repository/repositories
svn_log(path_to_repo = NULL)svn_log(path_to_repo = NULL)
path_to_repo |
path(s) to the folder(s) whose status to query (if NULL it uses the working directory). Can be a vector. |
list of dataframes containing repo, revision, user, date, number of lines and commit message
# svn_log(path_to_some_repo)# svn_log(path_to_some_repo)
Get SVN revision number
svn_revnum(path_to_repo = NULL, update = TRUE)svn_revnum(path_to_repo = NULL, update = TRUE)
path_to_repo |
path to repo(s) |
update |
perform an svn update before getting the revision number? |
number or list of numbers
# svn_revnum(path_to_some_repo)# svn_revnum(path_to_some_repo)
States of files in repo
svn_state(path_to_repo = NULL, ignored = FALSE)svn_state(path_to_repo = NULL, ignored = FALSE)
path_to_repo |
path(s) to the folder(s) whose status to query (if NULL it uses the working directory). Can be a vector. |
ignored |
logical. Return ignored/unversioned files only? |
list containing lists of each type of file status (e.g. added (add), deleted (delete), ...)
# svn_state(path_to_some_repo)# svn_state(path_to_some_repo)